@@ -843,11 +843,11 @@ int AWindow::createXIC()
     inputcontext = XCreateIC( _aguix->getXIM(),
 			      XNInputStyle, _aguix->getXIMStyle(),
 			      XNClientWindow, win,
-			      NULL );
+			      (void*)NULL );
     if ( inputcontext == NULL ) {
       fprintf( stderr, "Worker Warning: Cannot create input context\n");
     } else {
-      XGetICValues( inputcontext, XNFilterEvents, &im_event_mask, NULL );
+      XGetICValues( inputcontext, XNFilterEvents, &im_event_mask, (void*)NULL );
       XGetWindowAttributes( _aguix->getDisplay(), win, &attr );
       XSelectInput( _aguix->getDisplay(), win, attr.your_event_mask | im_event_mask );
     }
@@ -1369,3 +1369,11 @@ void AWindow::toFront()
     if ( _created == false ) return;
     _aguix->WindowtoFront( win );
 }
+
+void AWindow::updateCont()
+{
+    if ( container != NULL ) {
+        container->resize( getWidth(), getHeight() );
+        container->rearrange();
+    }
+}
