@@ -1,6 +1,6 @@
 /* karteibutton.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004-2007 Ralf Hoffmann.
+ * Copyright (C) 2004-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "karteibutton.h"
@@ -127,8 +127,9 @@ void KarteiButton::redraw()
       
       if ( run == 0 ) {
 	// left triangle
-	if ( i != act_opt && _aguix->extColorsAvail() == true ) {
-	  _aguix->setFG( usegc, AGUIX::EXTCOLOR_DARKGRAY );
+	if ( i != act_opt ) {
+          // dark grey
+          _aguix->setFG( usegc, AGUIXColor( 1, AGUIXColor::SYSTEM_COLOR ) );
 
 	  // top part of the triangle is always visible
 	  _aguix->DrawTriangleFilled( win, usegc, sx , sy, sx + dx, sy, sx + dx, 0 );
@@ -157,8 +158,9 @@ void KarteiButton::redraw()
       dx2 += 2 * delx;
       
       if ( run == 0 ) {
-	if ( i != act_opt && _aguix->extColorsAvail() == true ) {
-	  _aguix->setFG( usegc, AGUIX::EXTCOLOR_DARKGRAY );
+	if ( i != act_opt ) {
+          // dark grey
+          _aguix->setFG( usegc, AGUIXColor( 1, AGUIXColor::SYSTEM_COLOR ) );
 
 	  // this is the bg of an inactive option
 	  _aguix->FillRectangle( win, usegc, sx + dx, 0, dx2, basey );
@@ -178,8 +180,9 @@ void KarteiButton::redraw()
       }
 
       if ( run == 0 ) {
-	if ( i != act_opt && _aguix->extColorsAvail() == true ) {
-	  _aguix->setFG( usegc, AGUIX::EXTCOLOR_DARKGRAY );
+	if ( i != act_opt ) {
+          // dark grey
+          _aguix->setFG( usegc, AGUIXColor( 1, AGUIXColor::SYSTEM_COLOR ) );
 
 	  // finally the right triangle
 	  _aguix->DrawTriangleFilled( win, usegc, sx + dx + dx2 , 0, sx + dx + dx2, basey, sx + dx + dx2 + 2 * delx, basey );
