@@ -1,6 +1,6 @@
 /* stringgadget.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2006 Ralf Hoffmann.
+ * Copyright (C) 2001-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* $Id: stringgadget.cc,v 1.54 2005/12/12 20:45:29 ralf Exp $ */
 
 #include "stringgadget.h"
 #include "awindow.h"
@@ -910,13 +909,16 @@ void StringGadget::insertAtCursor( const char *str )
   textRedraw();
 }
 
-void StringGadget::selectAll()
+void StringGadget::selectAll( bool copy_selection )
 {
   content.setCursorPos( (int)strlen(content.getText()) );
   setXOffset( content.getCursorPos() );
   content.setSelStart( 0 );
   content.setSelEnd( content.getCursorPos() );
-  applySelection();
+
+  if ( copy_selection == true ) {
+      applySelection();
+  }
   redraw();
 }
 
