@@ -331,21 +331,35 @@
      CUSTOMACTION_WCP = 557,
      SAVE_WORKER_STATE_ON_EXIT_WCP = 558,
      OPENWORKERMENUOP_WCP = 559,
-     ERROR = 560,
-     ACTIVESIDE_WCP = 561,
-     SHOWFREESPACE_WCP = 562,
-     ACTIVEMODE_WCP = 563,
-     ASK_WCP = 564,
-     SSHALLOW_WCP = 565,
-     FIELD_WIDTH_WCP = 566,
-     QUICKSEARCHENABLED_WCP = 567,
-     FILTEREDSEARCHENABLED_WCP = 568,
-     XFTFONTS_WCP = 569,
-     USEMAGIC_WCP = 570,
-     MAGICPATTERN_WCP = 571,
-     MAGICCOMPRESSED_WCP = 572,
-     STRING_WCP = 573,
-     NUM_WCP = 574
+     CHANGELABELOP_WCP = 560,
+     ASKFORLABEL_WCP = 561,
+     LABELCOLORS_WCP = 562,
+     BOOKMARKLABEL_WCP = 563,
+     BOOKMARKFILTER_WCP = 564,
+     SHOWONLYBOOKMARKS_WCP = 565,
+     SHOWONLYLABEL_WCP = 566,
+     SHOWALL_WCP = 567,
+     OPTIONMODE_WCP = 568,
+     INVERT_WCP = 569,
+     SET_WCP = 570,
+     CHANGEFILTERS_WCP = 571,
+     CHANGEBOOKMARKS_WCP = 572,
+     QUERYLABEL_WCP = 573,
+     ERROR = 574,
+     ACTIVESIDE_WCP = 575,
+     SHOWFREESPACE_WCP = 576,
+     ACTIVEMODE_WCP = 577,
+     ASK_WCP = 578,
+     SSHALLOW_WCP = 579,
+     FIELD_WIDTH_WCP = 580,
+     QUICKSEARCHENABLED_WCP = 581,
+     FILTEREDSEARCHENABLED_WCP = 582,
+     XFTFONTS_WCP = 583,
+     USEMAGIC_WCP = 584,
+     MAGICPATTERN_WCP = 585,
+     MAGICCOMPRESSED_WCP = 586,
+     STRING_WCP = 587,
+     NUM_WCP = 588
    };
 #endif
 /* Tokens.  */
@@ -651,33 +665,47 @@
 #define CUSTOMACTION_WCP 557
 #define SAVE_WORKER_STATE_ON_EXIT_WCP 558
 #define OPENWORKERMENUOP_WCP 559
-#define ERROR 560
-#define ACTIVESIDE_WCP 561
-#define SHOWFREESPACE_WCP 562
-#define ACTIVEMODE_WCP 563
-#define ASK_WCP 564
-#define SSHALLOW_WCP 565
-#define FIELD_WIDTH_WCP 566
-#define QUICKSEARCHENABLED_WCP 567
-#define FILTEREDSEARCHENABLED_WCP 568
-#define XFTFONTS_WCP 569
-#define USEMAGIC_WCP 570
-#define MAGICPATTERN_WCP 571
-#define MAGICCOMPRESSED_WCP 572
-#define STRING_WCP 573
-#define NUM_WCP 574
+#define CHANGELABELOP_WCP 560
+#define ASKFORLABEL_WCP 561
+#define LABELCOLORS_WCP 562
+#define BOOKMARKLABEL_WCP 563
+#define BOOKMARKFILTER_WCP 564
+#define SHOWONLYBOOKMARKS_WCP 565
+#define SHOWONLYLABEL_WCP 566
+#define SHOWALL_WCP 567
+#define OPTIONMODE_WCP 568
+#define INVERT_WCP 569
+#define SET_WCP 570
+#define CHANGEFILTERS_WCP 571
+#define CHANGEBOOKMARKS_WCP 572
+#define QUERYLABEL_WCP 573
+#define ERROR 574
+#define ACTIVESIDE_WCP 575
+#define SHOWFREESPACE_WCP 576
+#define ACTIVEMODE_WCP 577
+#define ASK_WCP 578
+#define SSHALLOW_WCP 579
+#define FIELD_WIDTH_WCP 580
+#define QUICKSEARCHENABLED_WCP 581
+#define FILTEREDSEARCHENABLED_WCP 582
+#define XFTFONTS_WCP 583
+#define USEMAGIC_WCP 584
+#define MAGICPATTERN_WCP 585
+#define MAGICCOMPRESSED_WCP 586
+#define STRING_WCP 587
+#define NUM_WCP 588
 
 
 
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 204 "configparser.y"
+#line 210 "configparser.y"
 typedef union YYSTYPE {
   int num;
   char *strptr;
 } YYSTYPE;
-/* Line 1447 of yacc.c.  */
-#line 681 "configparser.tab.h"
+/* Line 1403 of yacc.c.  */
+#line 709 "configparser.tab.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
