@@ -336,7 +336,21 @@ struct mytoken tokenlist[]={
   { XFTFONTS_WCP, "xftfonts" },
   { USEMAGIC_WCP, "usemagic" },
   { MAGICCOMPRESSED_WCP, "magiccompressed" },
-  { MAGICPATTERN_WCP, "magicpattern" }
+  { MAGICPATTERN_WCP, "magicpattern" },
+  { CHANGELABELOP_WCP, "changelabelop" },
+  { ASKFORLABEL_WCP, "askforlabel" },
+  { LABELCOLORS_WCP, "labelcolors" },
+  { BOOKMARKLABEL_WCP, "bookmarklabel" },
+  { BOOKMARKFILTER_WCP, "bookmarkfilter" },
+  { SHOWONLYBOOKMARKS_WCP, "showonlybookmarks" },
+  { SHOWONLYLABEL_WCP, "showonlylabel" },
+  { SHOWALL_WCP, "showall" },
+  { OPTIONMODE_WCP, "optionmode" },
+  { INVERT_WCP, "invert" },
+  { SET_WCP, "set" },
+  { CHANGEFILTERS_WCP, "changefilters" },
+  { CHANGEBOOKMARKS_WCP, "changebookmarks" },
+  { QUERYLABEL_WCP, "querylabel" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
