@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "goftpop.h"
@@ -37,8 +37,6 @@ GoFTPOp::GoFTPOp() : FunctionProto()
   pass = "";
   avfs_module = "ftp";
   hasConfigure = true;
-
-  pw_stored = false;
 }
 
 GoFTPOp::~GoFTPOp()
@@ -97,7 +95,13 @@ GoFTPOp::run( WPUContext *wpu, ActionMessage *msg )
 	 ( tuser.length() < 1 ) ) {
       req->request( catalog.getLocale( 124 ), catalog.getLocale( 625 ), catalog.getLocale( 11 ) );
     } else {
-      if ( ( pw_stored == false ) || ( talways_store_pw == true ) ) {
+      std::string key = tuser;
+      key += "@";
+      key += thost;
+
+      if ( pw_stored.count( key ) < 1 ||
+           pw_stored[key] == false ||
+           talways_store_pw == true ) {
         str1 = "/#";
         str1 += tavfs_module;
         str1 += "_ctl:";
@@ -111,7 +115,7 @@ GoFTPOp::run( WPUContext *wpu, ActionMessage *msg )
 	d.putString( tpass.c_str() );
 	d.putString( "\n" );
 	d.close();
-	pw_stored = true;
+	pw_stored[key] = true;
       }
 
       if ( tdontenterftp == false ) {
