@@ -1,6 +1,6 @@
 /* informationmode.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2007 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,6 +28,7 @@
 #include "pdatei.h"
 #include "wcfiletype.hh"
 #include "fileentry.hh"
+#include "nmspecialsourceext.hh"
 
 const char *InformationMode::type="InformationMode";
 
@@ -252,7 +253,6 @@ void InformationMode::showinfos()
   char buffer[1024],
        buffer2[ MAXPATHLEN + 1024 + 2 * A_BYTESFORNUMBER( int ) ],  // I need space for realpath and also other stuff
                                                                     // but this is enough
-       buffer3[10],
        rights[3][4],
        *tstr, *str;
   char *bstr2;
@@ -260,11 +260,10 @@ void InformationMode::showinfos()
   loff_t size;
   const char *cstr;
   size_t bufferlen;
-  std::string bytestr, kbytestr, mbytestr, numbufs, numbuff, bstr1;
+  std::string bytestr, kbytestr, mbytestr, bstr1;
   
   float percent;
   struct tm *timeptr;
-  loff_t f1,s1;
   time_t tvar;
   char *istr;
   
@@ -520,20 +519,16 @@ void InformationMode::showinfos()
         percent /= (double)parentlister->getWorker()->PS_getSpace();
       } else percent=0.0;
 
-      tstr=buffer3;
-      s1 = parentlister->getWorker()->PS_getSpaceH( &tstr );
-      tstr=buffer2;
-      f1 = parentlister->getWorker()->PS_getFreeSpaceH( &tstr );
-      MakeLong2NiceStr( s1, numbufs, false );
-      MakeLong2NiceStr( f1, numbuff, false );
+      std::string spaceh, freeh;
 
-      snprintf( buffer, sizeof( buffer ), "%s: %s %s (%2.0f %%) %s %s %s", catalog.getLocale( 187 ),
-                numbuff.c_str(),
-                buffer2,
+      spaceh = parentlister->getWorker()->PS_getSpaceH();
+      freeh = parentlister->getWorker()->PS_getFreeSpaceH();
+
+      snprintf( buffer, sizeof( buffer ), "%s: %s (%2.0f %%) %s %s", catalog.getLocale( 187 ),
+                freeh.c_str(),
                 percent,
                 catalog.getLocale( 188 ),
-                numbufs.c_str(),
-                buffer3 );
+                spaceh.c_str() );
       buffer[ sizeof( buffer ) - 1 ] = '\0';
       nospaceinfo = false;
     } else {
