@@ -1,6 +1,6 @@
 /* normalmode.h
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2007 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -33,24 +33,29 @@
 #include <aguix/mutex.h>
 #include <aguix/condvar.h>
 #include <aguix/refcount.hh>
-#include "listermode.h"
-#include "datei.h"
-#include "copyop.h"
-#include "deleteop.h"
-#include "condparser.h"
+#include <aguix/popupmenu.hh>
 #include <map>
+#include <memory>
+#include "listermode.h"
+#include "condparser.h"
 #include "nmfilter.hh"
-#include "nmcacheentry.hh"
-#include "nmcopyopdir.hh"
-#include "nmextlist.hh"
-#include "nmspecialsourceext.hh"
 #include "dirfiltersettings.hh"
 #include "dirsortsettings.hh"
 #include "stringmatcher_fnmatch.hh"
+#include "dirbookmarkssettings.hh"
+#include "fileentry_customcolor.hh"
+#include <string>
 
 class Lister;
 class NMFieldListViewDND;
 class CopyOpWin;
+class NMBookmarkCB;
+class NM_specialsourceExt;
+class NMExtList;
+class NM_CopyOp_Dir;
+class NMCacheEntry;
+class DeleteOpWin;
+class FileEntry;
 
 struct NM_copyorder {
   char *destdir;
@@ -226,6 +231,7 @@ public:
   typedef enum {NM_FILTER_INCLUDE,NM_FILTER_EXCLUDE,NM_FILTER_UNSET} nm_filter_t;
   void unsetAllFilters();
   void setFilter(const char *filter,nm_filter_t mode);
+    nm_filter_t checkFilter( const char *filter ) throw( int );
 
   void slavehandler();
   static void freeExtList( List *extlist );
@@ -288,6 +294,21 @@ public:
   void deactivateFilteredSearch();
   
   void openContextMenu();
+  void bookmarksChanged();
+  void updateOnBookmarkChange();
+  void openLabelPopUp();
+
+    void setHighlightBookmarkPrefix( bool nv );
+    bool getHighlightBookmarkPrefix() const;
+
+    void setBookmarkFilter( DirFilterSettings::bookmark_filter_t v );
+    DirFilterSettings::bookmark_filter_t getBookmarkFilter() const;
+
+    void setSpecificBookmarkLabel( const std::string &l );
+    const std::string &getSpecificBookmarkLabel() const;
+
+    int queryLVDimensions( int &x, int &y,
+                           int &w, int &h );
 protected:
   /*
    * NM_specialsourceInt always stores a pointer to a FE
@@ -365,7 +386,7 @@ protected:
   bool showfreespace;
   int updatetime;
   time_t lastfsupdate;
-  char *namestr;
+  std::string namestr;
   char *freespacestr;
   enum ssh_allow_t { SSH_ASK, SSH_NEVER, SSH_ALWAYS } ssh_allow;
   
@@ -416,7 +437,7 @@ protected:
 
   int requestNewMode( FileEntry *fe, changemod_info_t *return_mode );
   void setFilters( const std::list<NM_Filter> &filters );
-  void configureFilters( bool * tshowhidden, std::list<NM_Filter> &filters );
+    void configureFilters( bool * tshowhidden, std::list<NM_Filter> &filters, DirFilterSettings &dir_settings );
   void setLVC4Filter( FieldListView *filv, int row, NM_Filter &fi);
   int configureFilter( NM_Filter &fi );
   void rebuildView();
@@ -431,7 +452,6 @@ protected:
   void setFilteredSearchEnabled( bool nv );
   
   static int maxfilestrlen,maxdirstrlen,maxbytesstrlen,maxwbytesstrlen,maxnochanges;
-  
 public:   // why the h*** need the Sun compiler a public definition for a
           // protected struct?
   typedef enum { THREAD_NOP,
@@ -519,22 +539,17 @@ protected:
     public:
       char *name;
       std::vector<unsigned int> *ft_index;
-      bool customcolors;
-      int *fg, *bg;
+      std::auto_ptr<FileEntryCustomColor> custom_color;
       ft_recres_list_t *next;
 
       ft_recres_list_t()
       {
 	name = NULL;
 	ft_index = NULL;
-	customcolors = false;
-	fg = bg = NULL;
 	next = NULL;
       }
       ~ft_recres_list_t()
       {
-	if ( fg != NULL ) delete [] fg;
-	if ( bg != NULL ) delete [] bg;
         if ( name != NULL ) _freesafe( name );
         if ( ft_index != NULL ) delete ft_index;
       }
@@ -569,18 +584,18 @@ protected:
 
   class checkFiletypeRes_t {
   public:
+      //TODO use auto_ptr?
     std::vector<unsigned int> *v;
-    bool customcolors;
-    int *fg, *bg;
+    std::auto_ptr<FileEntryCustomColor> custom_color;
     
     checkFiletypeRes_t() {
       v = NULL;
-      fg = bg = NULL;
-      customcolors = false;
     }
+    checkFiletypeRes_t( const checkFiletypeRes_t &other );
+    checkFiletypeRes_t &operator=( const checkFiletypeRes_t &rhs );
   };
   
-  checkFiletypeRes_t slave_checkFiletype( const char *fullname, bool dontCheckContent );
+  int slave_checkFiletype( const char *fullname, bool dontCheckContent, checkFiletypeRes_t &res_return );
   
   bool lasteagain;
   
@@ -657,6 +672,7 @@ protected:
 
   DirFilterSettings _dir_filter_sets;
   DirSortSettings _dir_sort_sets;
+  DirBookmarksSettings m_dir_bookmarks_sets;
 
   bool checkEnterDir( const char *dir2 );
 
@@ -676,16 +692,52 @@ protected:
   int buildSpecialSourceIntList( const std::list<NM_specialsourceExt*> &inlist,
                                  std::list<NM_specialsourceInt*> &outlist );
   
-  class PopUpMenu *m_lv_popup_menu;
-  std::auto_ptr<FileEntry> m_entry_for_popup;
-
-  std::map<int, RefCount<ActionDescr> > m_popup_descr;
-
   void lv_pressed( int row, bool open_under_mouse = true );
-  void buildPopUpMenu( FileEntry *entry );
+  void buildContextPopUpMenu( FileEntry *entry );
+  void buildLabelPopUpMenu( FileEntry *entry );
+  void freePopUpMenus();
   void startLVPopUpAction( AGMessage *msg );
 
   time_t m_last_statebar_update;
+  bool m_bookmarks_has_been_changed;
+  NMBookmarkCB *m_bookmark_cb;
+
+    std::list<PopUpMenu::PopUpEntry> buildLabelPopUpData( FileEntry *entry );
+    void handleLabelPopUp( AGMessage *msg );
+    void handleLabelPopUp( FileEntry *fe, const std::list<int> &entry_ids );
+
+    typedef struct _label_popup_table_t {
+        typedef enum { REMOVE_LABEL, ADD_LABEL } label_popup_t;
+
+        _label_popup_table_t() : type( REMOVE_LABEL ),
+                                 label( "" )
+        {}
+        _label_popup_table_t( label_popup_t t, const std::string &l ) : type( t ),
+                                                                        label( l )
+        {}
+
+        label_popup_t type;
+        std::string label;
+    } label_popup_table_t;
+
+    class PopUpSettings {
+    public:
+        PopUpSettings();
+        PopUpSettings( const PopUpSettings &other );
+        PopUpSettings &operator=( const PopUpSettings &rhs );
+
+        void reset();
+
+        int label_menu_id;
+        std::map<int, label_popup_table_t> label_id_to_action;
+        std::auto_ptr<PopUpMenu> label_popup_menu;
+
+        std::map<int, RefCount<ActionDescr> > popup_descr;
+        std::auto_ptr<FileEntry> entry_for_popup;
+        PopUpMenu *lv_popup_menu;
+    };
+
+    PopUpSettings m_current_popup_settings;
 };
 
 class NMFieldListViewDND:public FieldListViewDND
@@ -704,3 +756,6 @@ protected:
 
 #endif
 
+/* Local Variables: */
+/* mode:c++ */
+/* End: */
