@@ -31,6 +31,8 @@
 #include <aguix/acontainerbb.h>
 #include <typeinfo>
 #include "filenameshrinker.hh"
+#include <aguix/kartei.h>
+#include "calendar.hh"
 
 const char *SearchOp::name = "SearchOp";
 std::list<SearchOp::ResultStore*> SearchOp::_stored_results;
@@ -58,6 +60,15 @@ SearchOp::SearchOp() : FunctionProto(),
                        _follow_symlinks_cb( NULL ),
                        _search_vfs_cb( NULL ),
                        _search_same_fs_cb( NULL ),
+                       m_younger_cb( NULL ),
+                       m_older_cb( NULL ),
+                       m_younger_sg( NULL ),
+                       m_older_sg( NULL ),
+                       m_size_geq_cb( NULL ),
+                       m_size_leq_cb( NULL ),
+                       m_size_geq_sg( NULL ),
+                       m_size_leq_sg( NULL ),
+                       m_options_k1( NULL ),
                        _search_started( false )
 {
   _edit_command = DEFAULT_EDIT_COMMAND;
@@ -139,12 +150,25 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  AContainerBB *ac1_1 = dynamic_cast<AContainerBB*>( ac1->add( new AContainerBB( win, 1, 2 ), 0, 0 ) );
+  AContainerBB *ac1_1 = dynamic_cast<AContainerBB*>( ac1->add( new AContainerBB( win, 1, 1 ), 0, 0 ) );
   ac1_1->setMinSpace( 5 );
   ac1_1->setMaxSpace( 5 );
   ac1_1->setBorderWidth( 5 );
 
-  _start_ac = ac1_1->add( new AContainer( win, 2, 3 ), 0, 0 );
+  m_options_k1 = new Kartei( aguix, 10, 10, 10, 10, 0, "" );
+  ac1_1->add( m_options_k1, 0, 0, AContainer::CINCW );
+  m_options_k1->create();
+
+  AWindow *subwin1 = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  m_options_k1->add( subwin1 );
+  subwin1->create();
+
+  AContainer *acsw1_1 = subwin1->setContainer( new AContainer( subwin1, 1, 2 ), true );
+  acsw1_1->setMinSpace( 5 );
+  acsw1_1->setMaxSpace( 5 );
+  acsw1_1->setBorderWidth( 5 );
+
+  _start_ac = acsw1_1->add( new AContainer( subwin1, 2, 3 ), 0, 0 );
   _start_ac->setMinSpace( 5 );
   _start_ac->setMaxSpace( 5 );
   _start_ac->setBorderWidth( 0 );
@@ -155,7 +179,7 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
   _startdir_sg = (StringGadget*)_start_ac->add( new StringGadget( aguix, 0, 0, 100, _initial_start_dir.c_str(), 0 ), 1, 0, AContainer::CINCW );
   _startdir_text->resize( _startdir_text->getWidth(), _startdir_sg->getHeight() );
 
-  AContainer *ac1_2 = _start_ac->add( new AContainer( win, 4, 1 ), 1, 1 );
+  AContainer *ac1_2 = _start_ac->add( new AContainer( subwin1, 4, 1 ), 1, 1 );
   ac1_2->setMinSpace( 0 );
   ac1_2->setMaxSpace( 0 );
   ac1_2->setBorderWidth( 0 );
@@ -173,7 +197,7 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
   _matchname_case_cb->resize( _matchname_sg->getHeight(), _matchname_sg->getHeight() );
   ac1_2->readLimits();
   
-  AContainer *ac1_3 = _start_ac->add( new AContainer( win, 2, 1 ), 1, 2 );
+  AContainer *ac1_3 = _start_ac->add( new AContainer( subwin1, 2, 1 ), 1, 2 );
   ac1_3->setMinSpace( 0 );
   ac1_3->setMaxSpace( 0 );
   ac1_3->setBorderWidth( 0 );
@@ -185,7 +209,7 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
   _matchcontent_case_cb->resize( _matchcontent_sg->getHeight(), _matchcontent_sg->getHeight() );
   ac1_3->readLimits();
 
-  AContainer *ac1_globsets = ac1_1->add( new AContainer( win, 5, 1 ), 0, 1 );
+  AContainer *ac1_globsets = acsw1_1->add( new AContainer( subwin1, 5, 1 ), 0, 1 );
   ac1_globsets->setMinSpace( 5 );
   ac1_globsets->setMaxSpace( 5 );
   ac1_globsets->setBorderWidth( 0 );
@@ -204,6 +228,48 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
                                                                0,
                                                                0 ), 4, 0, AContainer::CFIX );
 
+  AWindow *subwin2 = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  m_options_k1->add( subwin2 );
+  subwin2->create();
+
+  AContainer *acsw2_1 = subwin2->setContainer( new AContainer( subwin2, 1, 2 ), true );
+  acsw2_1->setMinSpace( 5 );
+  acsw2_1->setMaxSpace( 5 );
+  acsw2_1->setBorderWidth( 5 );
+
+  AContainer *acsub1 = acsw2_1->add( new AContainer( subwin2, 6, 1 ), 0, 0 );
+  acsub1->setMinSpace( 5 );
+  acsub1->setMaxSpace( 5 );
+  acsub1->setBorderWidth( 0 );
+
+  m_younger_cb = (ChooseButton*)acsub1->add( new ChooseButton( aguix, 0, 0, false,
+                                                               catalog.getLocale( 813 ), LABEL_RIGHT, 1, 0 ), 0, 0, AContainer::CFIXNR );
+  m_younger_sg = (StringGadget*)acsub1->add( new StringGadget( aguix, 0, 0, 100, "", 0 ), 1, 0, AContainer::CINCW );
+  Button *younger_cal_b = (Button*)acsub1->add( new Button( aguix, 0, 0, catalog.getLocale( 819 ), 1, 0, 0 ), 2, 0, AContainer::CFIX );
+  m_older_cb = (ChooseButton*)acsub1->add( new ChooseButton( aguix, 0, 0, false,
+                                                             catalog.getLocale( 814 ), LABEL_RIGHT, 1, 0 ), 3, 0, AContainer::CFIXNR );
+  m_older_sg = (StringGadget*)acsub1->add( new StringGadget( aguix, 0, 0, 100, "", 0 ), 4, 0, AContainer::CINCW );
+  Button *older_cal_b = (Button*)acsub1->add( new Button( aguix, 0, 0, catalog.getLocale( 819 ), 1, 0, 0 ), 5, 0, AContainer::CFIX );
+
+  AContainer *acsub2 = acsw2_1->add( new AContainer( subwin2, 5, 1 ), 0, 1 );
+  acsub2->setMinSpace( 5 );
+  acsub2->setMaxSpace( 5 );
+  acsub2->setBorderWidth( 0 );
+
+  m_size_geq_cb = (ChooseButton*)acsub2->add( new ChooseButton( aguix, 0, 0, false,
+                                                                catalog.getLocale( 817 ), LABEL_RIGHT, 1, 0 ), 0, 0, AContainer::CFIXNR );
+  m_size_geq_sg = (StringGadget*)acsub2->add( new StringGadget( aguix, 0, 0, 100, "", 0 ), 1, 0, AContainer::CINCW );
+  m_size_leq_cb = (ChooseButton*)acsub2->add( new ChooseButton( aguix, 0, 0, false,
+                                                                catalog.getLocale( 818 ), LABEL_RIGHT, 1, 0 ), 2, 0, AContainer::CFIXNR );
+  m_size_leq_sg = (StringGadget*)acsub2->add( new StringGadget( aguix, 0, 0, 100, "", 0 ), 3, 0, AContainer::CINCW );
+  Button *size_help_b = (Button*)acsub2->add( new Button( aguix, 0, 0, catalog.getLocale( 483 ), 1, 0, 0 ), 4, 0, AContainer::CFIX );
+
+  m_options_k1->setOption( subwin1, 0, catalog.getLocale( 815 ) );
+  m_options_k1->setOption( subwin2, 1, catalog.getLocale( 816 ) );
+  m_options_k1->maximize();
+  m_options_k1->contMaximize();
+  ac1_1->readLimits();
+  
   AContainer *ac1_res = ac1->add( new AContainer( win, 1, 2 ), 0, 1 );
   ac1_res->setMinSpace( 5 );
   ac1_res->setMaxSpace( 5 );
@@ -352,6 +418,7 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
   _matchcontent_sg->selectAll( false );
 
   win->show();
+  m_options_k1->show();
   msg->getWorker()->setWaitCursor();
 
   int update_ctr = 0;
@@ -391,6 +458,23 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
             viewResult();
           } else if ( agmsg->button.button == editb ) {
             editResult();
+          } else if ( agmsg->button.button == younger_cal_b ) {
+              Calendar c;
+              c.setInitialDate( m_younger_sg->getText() );
+              if ( c.showCalendar() ) {
+                  m_younger_sg->setText( c.getDate().c_str() );
+                  m_younger_cb->setState( true );
+              }
+          } else if ( agmsg->button.button == older_cal_b ) {
+              Calendar c;
+              c.setInitialDate( m_older_sg->getText() );
+              if ( c.showCalendar() ) {
+                  m_older_sg->setText( c.getDate().c_str() );
+                  m_older_cb->setState( true );
+              }
+          } else if ( agmsg->button.button == size_help_b ) {
+              Requester req( aguix, win );
+              req.request( catalog.getLocale( 124 ), catalog.getLocale( 820 ), catalog.getLocale( 11 ) );
           }
           break;
         case AG_FIELDLV_ONESELECT:
@@ -429,6 +513,14 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
               }
           } else if ( agmsg->stringgadget.sg == _matchcontent_sg ) {
             startSearch();
+          } else if ( agmsg->stringgadget.sg == m_younger_sg ) {
+              m_younger_cb->setState( true );
+          } else if ( agmsg->stringgadget.sg == m_older_sg ) {
+              m_older_cb->setState( true );
+          } else if ( agmsg->stringgadget.sg == m_size_geq_sg ) {
+              m_size_geq_cb->setState( true );
+          } else if ( agmsg->stringgadget.sg == m_size_leq_sg ) {
+              m_size_leq_cb->setState( true );
           }
           break;
         case AG_KEYPRESSED:
@@ -799,12 +891,7 @@ void SearchOp::startSearch()
   use_dir->walk( dw1 );
 
   _sth = new SearchThread( std::auto_ptr<NWC::Dir>( use_dir ) );
-  _sth->setMatchName( sets.getMatchName() );
-  _sth->setMatchFullpath( sets.getMatchNameFullPath() );
-  _sth->setMatchRegExp( sets.getMatchNameRE() );
-  _sth->setMatchCaseSensitive( sets.getMatchNameCase() );
-  _sth->setMatchContent( sets.getMatchContent() );
-  _sth->setMatchContentCaseSensitive( sets.getMatchContentCase() );
+  _sth->setSearchSettings( sets );
   _sth->start();
 
   storeSearchSettings();
@@ -872,10 +959,11 @@ void SearchOp::newSearch()
   }
 
   prepareNewSearch();
+  m_options_k1->optionChange( 0 );
   _matchname_sg->takeFocus();
 }
 
-SearchOp::SearchSettings SearchOp::getCurrentSearchSettings()
+SearchSettings SearchOp::getCurrentSearchSettings()
 {
   SearchSettings sets( _startdir_sg->getText(),
                        _matchname_sg->getText(),
@@ -886,7 +974,16 @@ SearchOp::SearchSettings SearchOp::getCurrentSearchSettings()
                        _matchcontent_case_cb->getState(),
                        _follow_symlinks_cb->getState(),
                        _search_vfs_cb->getState(),
-                       _search_same_fs_cb->getState() );
+                       _search_same_fs_cb->getState(),
+                       m_younger_cb->getState(),
+                       m_younger_sg->getText(),
+                       m_older_cb->getState(),
+                       m_older_sg->getText() );
+
+  sets.setCheckSizeGEQ( m_size_geq_cb->getState() );
+  sets.setCheckSizeLEQ( m_size_leq_cb->getState() );
+  sets.setSizeGEQ( m_size_geq_sg->getText() );
+  sets.setSizeLEQ( m_size_leq_sg->getText() );
   return sets;
 }
 
@@ -914,6 +1011,15 @@ void SearchOp::restoreSearchSettings()
   _follow_symlinks_cb->setState( sets.getFollowSymlinks() );
   _search_vfs_cb->setState( sets.getSearchVFS() );
   _search_same_fs_cb->setState( sets.getSearchSameFS() );
+  m_younger_cb->setState( sets.getCheckYounger() );
+  m_younger_sg->setText( sets.getYoungerThan().c_str() );
+  m_older_cb->setState( sets.getCheckOlder() );
+  m_older_sg->setText( sets.getOlderThan().c_str() );
+
+  m_size_geq_cb->setState( sets.getCheckSizeGEQ() );
+  m_size_leq_cb->setState( sets.getCheckSizeLEQ() );
+  m_size_geq_sg->setText( sets.getSizeGEQ().c_str() );
+  m_size_leq_sg->setText( sets.getSizeLEQ().c_str() );
 }
 
 void SearchOp::setCurrentResultStore( int pos, const SearchSettings *sets )
@@ -949,6 +1055,15 @@ void SearchOp::cleanupPtrs()
   _follow_symlinks_cb = NULL;
   _search_vfs_cb = NULL;
   _search_same_fs_cb = NULL;
+  m_younger_cb = NULL;
+  m_older_cb = NULL;
+  m_younger_sg = NULL;
+  m_older_sg = NULL;
+  m_size_geq_cb = NULL;
+  m_size_leq_cb = NULL;
+  m_size_geq_sg = NULL;
+  m_size_leq_sg = NULL;
+  m_options_k1 = NULL;
 }
 
 void SearchOp::removeSelectedResults()
