@@ -1,6 +1,6 @@
 /* searchthread.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006 Ralf Hoffmann.
+ * Copyright (C) 2006-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,13 +28,7 @@
 #include <iostream>
 
 SearchThread::SearchThread( std::auto_ptr<NWC::Dir> searchdir ) : _current_mode( SEARCHING ),
-                                                                  _mode_order( SEARCH ),
-                                                                  _matchname( "" ),
-                                                                  _match_fullpath( false ),
-                                                                  _match_regexp( false ),
-                                                                  _match_case_sensitive( true ),
-                                                                  _match_content( "" ),
-                                                                  _match_content_casesens( false )
+                                                                  _mode_order( SEARCH )
 {
   _searchdir = searchdir.release();
 }
@@ -108,32 +102,73 @@ SearchThread::search_mode_t SearchThread::getCurrentMode()
 
 int SearchThread::visit( NWC::File &file, NWC::Dir::WalkControlObj &cobj )
 {
-  if ( checkName( _match_fullpath == true ? file.getFullname() : file.getBasename() ) == true ) {
-    checkContent( file );
-  }
-  
-  if ( checkInterrupt() == true ) {
-    cobj.setMode( NWC::Dir::WalkControlObj::ABORT );
-  }
-  return 0;
+    bool candidate = true;
+
+    if ( m_sets.getCheckYounger() == true && file.stat_lastmod() < m_sets.getYoungerThanDate() ) {
+        candidate = false;
+    } else if ( m_sets.getCheckOlder() == true && file.stat_lastmod() > m_sets.getOlderThanDate() ) {
+        candidate = false;
+    } else if ( m_sets.getCheckSizeGEQ() == true ||
+                m_sets.getCheckSizeLEQ() == true ) {
+        if ( file.isReg( m_sets.getFollowSymlinks() ) == true ) {
+            loff_t filesize = 0;
+            if ( file.isLink() == true && m_sets.getFollowSymlinks() == true ) {
+                filesize = file.stat_dest_size();
+            } else {
+                filesize = file.stat_size();
+            }
+
+            if ( m_sets.getCheckSizeGEQ() == true && filesize < m_sets.getSizeGEQAsInt() ) {
+                candidate = false;
+            } else if ( m_sets.getCheckSizeLEQ() == true && filesize > m_sets.getSizeLEQAsInt() ) {
+                candidate = false;
+            }
+        } else {
+            candidate = false;
+        }
+    }
+
+    if ( candidate == true ) {
+        if ( checkName( m_sets.getMatchNameFullPath() == true ? file.getFullname() : file.getBasename() ) == true ) {
+            checkContent( file );
+        }
+    }
+    
+    if ( checkInterrupt() == true ) {
+        cobj.setMode( NWC::Dir::WalkControlObj::ABORT );
+    }
+    return 0;
 }
 
 int SearchThread::visitEnterDir( NWC::Dir &dir, NWC::Dir::WalkControlObj &cobj )
 {
-  _current_action_lock.lock();
-  _current_action = catalog.getLocale( 747 );
-  _current_action += dir.getFullname();
-  _current_action_lock.unlock();
-  
-  if ( checkName( _match_fullpath == true ? dir.getFullname() : dir.getBasename() ) == true ) {
-    if ( _match_content.length() < 1 ) {
-      _result_lock.lock();
-      _results.push_back( SearchResult( dir.getFullname(), -1, true ) );
-      _result_lock.unlock();
+    bool candidate = true;
+    
+    _current_action_lock.lock();
+    _current_action = catalog.getLocale( 747 );
+    _current_action += dir.getFullname();
+    _current_action_lock.unlock();
+    
+    if ( m_sets.getCheckYounger() == true && dir.stat_lastmod() < m_sets.getYoungerThanDate() ) {
+        candidate = false;
+    } else if ( m_sets.getCheckOlder() == true && dir.stat_lastmod() > m_sets.getOlderThanDate() ) {
+        candidate = false;
+    } else if ( m_sets.getCheckSizeGEQ() == true ||
+                m_sets.getCheckSizeLEQ() == true ) {
+        candidate = false;
     }
-  }
-  
-  return 0;
+
+    if ( candidate == true ) {
+        if ( checkName( m_sets.getMatchNameFullPath() == true ? dir.getFullname() : dir.getBasename() ) == true ) {
+            if ( m_sets.getMatchContent().length() < 1 ) {
+                _result_lock.lock();
+                _results.push_back( SearchResult( dir.getFullname(), -1, true ) );
+                _result_lock.unlock();
+            }
+        }
+    }
+    
+    return 0;
 }
 
 int SearchThread::visitLeaveDir( NWC::Dir &dir, NWC::Dir::WalkControlObj &cobj )
@@ -141,44 +176,14 @@ int SearchThread::visitLeaveDir( NWC::Dir &dir, NWC::Dir::WalkControlObj &cobj )
   return 0;
 }
 
-void SearchThread::setMatchName( const std::string &name )
-{
-  _matchname = name;
-}
-
-void SearchThread::setMatchFullpath( bool nv )
-{
-  _match_fullpath = nv;
-}
-
-void SearchThread::setMatchRegExp( bool nv )
-{
-  _match_regexp = nv;
-}
-
-void SearchThread::setMatchCaseSensitive( bool nv )
-{
-  _match_case_sensitive = nv;
-}
-
-void SearchThread::setMatchContent( const std::string &content )
-{
-  _match_content = content;
-}
-
-void SearchThread::setMatchContentCaseSensitive( bool nv )
-{
-  _match_content_casesens = nv;
-}
-
 bool SearchThread::checkName( const std::string &str )
 {
-  if ( _match_regexp == true ) {
-    return re.match( _matchname.c_str(), str.c_str(), ( _match_case_sensitive == false ) ? true : false );
+  if ( m_sets.getMatchNameRE() == true ) {
+      return re.match( m_sets.getMatchName().c_str(), str.c_str(), ( m_sets.getMatchNameCase() == false ) ? true : false );
   } else {
-    if ( _match_case_sensitive == false ) {
+    if ( m_sets.getMatchNameCase() == false ) {
 #ifdef HAVE_GNU_FNMATCH
-      if ( fnmatch( _matchname.c_str(), str.c_str(), FNM_CASEFOLD ) == 0 ) return true;
+      if ( fnmatch( m_sets.getMatchName().c_str(), str.c_str(), FNM_CASEFOLD ) == 0 ) return true;
 #else
       bool matched = false;
       char *lstr, *pstr;
@@ -189,7 +194,7 @@ bool SearchThread::checkName( const std::string &str )
       for ( i = 0; lstr[i] != '\0'; i++ )
         lstr[i] = tolower( lstr[i] );
       
-      pstr = dupstring( _matchname.c_str() );
+      pstr = dupstring( m_sets.getMatchName().c_str() );
       for ( i = 0; pstr[i] != '\0'; i++ )
         pstr[i] = tolower( pstr[i] );
       
@@ -199,7 +204,7 @@ bool SearchThread::checkName( const std::string &str )
       return matched;
 #endif
     } else {
-      if ( fnmatch( _matchname.c_str(), str.c_str(), 0 ) == 0 ) return true;
+        if ( fnmatch( m_sets.getMatchName().c_str(), str.c_str(), 0 ) == 0 ) return true;
     }
   }
   return false;                                                                 
@@ -208,7 +213,7 @@ bool SearchThread::checkName( const std::string &str )
 int SearchThread::matchContentLine( const NWC::File &file, const char *line, int current_line )
 {
   int found = 0;
-  if ( re.match( _match_content.c_str(), line, ( _match_content_casesens == true ) ? false : true ) == true ) {
+  if ( re.match( m_sets.getMatchContent().c_str(), line, ( m_sets.getMatchContentCase() == true ) ? false : true ) == true ) {
     _result_lock.lock();
     _results.push_back( SearchResult( file.getFullname(), current_line ) );
     _result_lock.unlock();
@@ -276,7 +281,7 @@ int SearchThread::checkContent( const NWC::File &file )
   if ( checkInterrupt() == true )
     return matches;
 
-  if ( _match_content.length() < 1 ) {
+  if ( m_sets.getMatchContent().length() < 1 ) {
     _result_lock.lock();
     _results.push_back( SearchResult( file.getFullname(), -1 ) );
     _result_lock.unlock();
@@ -379,3 +384,8 @@ std::string SearchThread::getCurrentActionInfo()
 
   return erg;
 }
+
+void SearchThread::setSearchSettings( const SearchSettings &sets )
+{
+    m_sets = sets;
+}
