@@ -55,6 +55,9 @@
 #include <iostream>
 #include <aguix/popupmenu.hh>
 #include "magic_db.hh"
+#include "bookmarkdb.hh"
+#include "bookmarkdbproxy.hh"
+#include <algorithm>
 
 Requester *Worker::req_static=NULL;
 int Worker::argc = 0;
@@ -63,6 +66,8 @@ std::string Worker::startcwd = "/";
 AGUIX *Worker::aguix = NULL;
 int Worker::workerInstances = 0;
 
+std::auto_ptr<BookmarkDBProxy> Worker::m_bookmarkproxy;
+
 short usr1signal = 0;
 
 #ifdef HAVE_SIGACTION
@@ -144,6 +149,8 @@ Worker::Worker(int targc,char **targv)
   waitcursorcount = 0;
   restart = false;
   configstarted = false;
+
+  m_interpret_recursion_depth = 0;
 }
 
 Worker::~Worker()
@@ -318,6 +325,8 @@ void Worker::run()
             if ( msg->popupmenu.menu == m_worker_menu ) {
                 startMenuAction( msg );
                 handleSub = false;
+            } else {
+                handlePopUps( msg );
             }
             break;
         default:
@@ -1149,6 +1158,16 @@ int Worker::interpret(List* coms,ActionMessage *msg)
   List *parentActionList = NULL;
 
   if ( ( coms == NULL ) || ( msg == NULL ) ) return 1;
+
+  if ( m_interpret_recursion_depth > m_interpret_max_recursion ) {
+      if ( getRequester() != NULL ) {
+          getRequester()->request( catalog.getLocale( 125 ), catalog.getLocale( 821 ), catalog.getLocale( 11 ) );
+      } else {
+          fprintf( stderr, "%s", catalog.getLocale( 821 ) );
+      }
+      return 1;
+  }
+  m_interpret_recursion_depth++;
   
   mainwin->forbidUserInput();
   usr1signal = 0;
@@ -1188,6 +1207,7 @@ int Worker::interpret(List* coms,ActionMessage *msg)
   }
 
   mainwin->permitUserInput();
+  m_interpret_recursion_depth--;
 #endif
   return 0;
 }
@@ -1208,6 +1228,8 @@ int Worker::activateShortkey(AGMessage *msg)
   bool found;
   if((msg->type==AG_KEYPRESSED)||(msg->type==AG_KEYRELEASED)) {
 
+      amsg.setKeyAction( true );
+
     if ( msg->type == AG_KEYPRESSED ) {
       // I will ignore here any modifier key because
       // it makes no sense (for me) to allow a single modifier press
@@ -1585,7 +1607,7 @@ int Worker::quit(int mode)
 void Worker::updateTime(void)
 {
   struct tm *timeptr;
-#ifdef HAVE_SYSINFO
+#if defined HAVE_SYS_SYSINFO_H && defined HAVE_SYSINFO
   struct sysinfo info;
   unsigned long freeram,freeswap;
 #endif
@@ -1625,7 +1647,7 @@ void Worker::updateTime(void)
       timeptr=localtime(&timep);
       str=asctime(timeptr);
       str[strlen(str)-1]=0;
-#ifdef HAVE_SYSINFO
+#if defined HAVE_SYS_SYSINFO_H && defined HAVE_SYSINFO
       if(cbm==WConfig::CLOCKBAR_MODE_TIMERAM) {
         sysinfo(&info);
         freeram = info.freeram / 1024;
@@ -2148,14 +2170,14 @@ loff_t Worker::PS_getSpace()
   return freesp->getSpace();
 }
 
-loff_t Worker::PS_getFreeSpaceH(char **unit_return)
+std::string Worker::PS_getFreeSpaceH() const
 {
-  return freesp->getFreeSpaceH( unit_return );
+  return freesp->getFreeSpaceH();
 }
 
-loff_t Worker::PS_getSpaceH(char **unit_return)
+std::string Worker::PS_getSpaceH() const
 {
-  return freesp->getSpaceH( unit_return );
+  return freesp->getSpaceH();
 }
 
 void Worker::buildtable()
@@ -3037,3 +3059,100 @@ int Worker::getStatebarWidth()
 {
     return statebar->getWidth() - 2 * 2;
 }
+
+BookmarkDBProxy &Worker::getBookmarkDBInstance()
+{
+    if ( m_bookmarkproxy.get() != NULL ) return *m_bookmarkproxy;
+
+    std::string cfgfile = Worker::getWorkerConfigDir();
+#ifdef DEBUG
+    cfgfile = NWC::Path::join( cfgfile, "bookmarks2" );
+#else
+    cfgfile = NWC::Path::join( cfgfile, "bookmarks" );
+#endif
+    m_bookmarkproxy.reset( new BookmarkDBProxy( std::auto_ptr<BookmarkDB>( new BookmarkDB( cfgfile ) ) ) );
+    m_bookmarkproxy->read();
+    return *m_bookmarkproxy;
+}
+
+struct cb_cmp : public std::unary_function<const RefCount<GenericCallbackArg<void, AGMessage*> >&, bool> {
+    cb_cmp( const RefCount<GenericCallbackArg<void, AGMessage*> > &entry ) : m_entry( entry )
+    {}
+    bool operator()( const RefCount<GenericCallbackArg<void, AGMessage*> > &other )
+    {
+        if ( other.getVal() == NULL || m_entry.getVal() == NULL ) return false;
+        if ( other.getVal() == m_entry.getVal() ) return true;
+        return false;
+    }
+    const RefCount<GenericCallbackArg<void, AGMessage*> > &m_entry;
+};
+
+void Worker::registerPopUpCallback( RefCount<GenericCallbackArg<void, AGMessage*> > cb,
+                                    const PopUpMenu *menu )
+{
+    std::map<const PopUpMenu *, std::list<RefCount<GenericCallbackArg<void, AGMessage*> > > >::iterator it1;
+
+    it1 = m_popup_callbacks.find( menu );
+
+    if ( it1 != m_popup_callbacks.end() ) {
+        if ( std::find_if( m_popup_callbacks[menu].begin(),
+                           m_popup_callbacks[menu].end(),
+                           cb_cmp( cb ) ) == m_popup_callbacks[menu].end() ) {
+            m_popup_callbacks[menu].push_back( cb );
+        }
+    } else {
+        m_popup_callbacks[menu].push_back( cb );
+    }
+}
+
+void Worker::unregisterPopUpCallback( RefCount<GenericCallbackArg<void, AGMessage*> > cb )
+{
+    std::map<const PopUpMenu *, std::list<RefCount<GenericCallbackArg<void, AGMessage*> > > >::iterator it1;
+    std::list<RefCount<GenericCallbackArg<void, AGMessage*> > >::iterator it2;
+
+    for ( it1 = m_popup_callbacks.begin();
+          it1 != m_popup_callbacks.end();
+          ++it1 ) {
+        it2 = std::find_if( it1->second.begin(),
+                            it1->second.end(),
+                            cb_cmp( cb ) );
+        if ( it2 != it1->second.end() ) {
+            it1->second.erase( it2 );
+        }
+    }
+}
+
+void Worker::handlePopUps( AGMessage *msg )
+{
+    if ( msg == NULL ) return;
+
+    if ( msg->type != AG_POPUPMENU_CLICKED ) return;
+
+    std::map<const PopUpMenu *, std::list<RefCount<GenericCallbackArg<void, AGMessage*> > > >::iterator it1;
+    std::list<RefCount<GenericCallbackArg<void, AGMessage*> > > temp_list;
+    std::list<RefCount<GenericCallbackArg<void, AGMessage*> > >::iterator it2;
+
+    it1 = m_popup_callbacks.find( msg->popupmenu.menu );
+
+    if ( it1 != m_popup_callbacks.end() ) {
+        // copy list because a callback might remove it from the list
+        // thus invalidating the iterator
+        temp_list = it1->second;
+        for ( it2 = temp_list.begin();
+              it2 != temp_list.end();
+              ++it2 ) {
+            (*it2)->callback( msg );
+        }
+    }
+
+    it1 = m_popup_callbacks.find( NULL );
+
+    if ( it1 != m_popup_callbacks.end() ) {
+        temp_list = it1->second;
+        for ( it2 = temp_list.begin();
+              it2 != temp_list.end();
+              ++it2 ) {
+            (*it2)->callback( msg );
+        }
+    }
+}
