@@ -36,9 +36,12 @@
 #include "partspace.h"
 #include <aguix/acontainer.h>
 #include <string>
+#include "generic_callback.hh"
 
 class ListerMode;
 class Lister;
+class BookmarkDBProxy;
+class PopUpMenu;
 
 class Worker
 {
@@ -82,8 +85,8 @@ public:
   loff_t PS_getFreeSpace();
   loff_t PS_getSpace();
   
-  loff_t PS_getFreeSpaceH(char **unit_return);
-  loff_t PS_getSpaceH(char **unit_return);
+  std::string PS_getFreeSpaceH() const;
+  std::string PS_getSpaceH() const;
   void PS_setLifetime( double t );
   void showLicense();
   void setWaitCursor();
@@ -100,6 +103,12 @@ public:
   void openWorkerMenu();
 
   int getStatebarWidth();
+
+  static BookmarkDBProxy &getBookmarkDBInstance();
+
+  void registerPopUpCallback( RefCount<GenericCallbackArg<void, AGMessage*> > cb,
+                              const PopUpMenu *menu );
+  void unregisterPopUpCallback( RefCount<GenericCallbackArg<void, AGMessage*> > cb );
  protected:
   void createMainWin();
   void setupMainWin();
@@ -182,9 +191,18 @@ public:
   std::string queryLanguage();
 
   void createWorkerMenu();
-  class PopUpMenu *m_worker_menu;
+  PopUpMenu *m_worker_menu;
   void startMenuAction( AGMessage *msg );
   void saveWorkerState();
+
+  int m_interpret_recursion_depth;
+  static const int m_interpret_max_recursion = 1000;
+
+  static std::auto_ptr<BookmarkDBProxy> m_bookmarkproxy;
+
+  std::map<const PopUpMenu *, std::list< RefCount<GenericCallbackArg<void, AGMessage*> > > > m_popup_callbacks;
+
+  void handlePopUps( AGMessage *msg );
 };
 
 #endif
