@@ -189,6 +189,9 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 54:
       fpr = new OpenWorkerMenuOp();
       break;
+    case 55:
+      fpr = new ChangeLabelOp();
+      break;
     default:
       fpr=new DNDAction();
   }
@@ -253,6 +256,7 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if ( fpr->isName( OpenContextMenuOp::name ) == true ) type = 52;
   else if ( fpr->isName( RunCustomAction::name ) == true ) type = 53;
   else if ( fpr->isName( OpenWorkerMenuOp::name ) == true ) type = 54;
+  else if ( fpr->isName( ChangeLabelOp::name ) == true ) type = 55;
   return type;
 }
 
