@@ -1,6 +1,6 @@
 /* worker_commands.h
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2007 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -57,6 +57,7 @@
 #include "opencontextmenuop.hh"
 #include "run_custom_action.hh"
 #include "openworkermenuop.hh"
+#include "changelabelop.hh"
 
 #include "listermode.h"
 #include "normalmode.h"
