@@ -24,8 +24,8 @@
 #include "worker.h"
 #include <aguix/utf8.hh>
 
-#define CATENTRY 813
-#define CATCOMENTRY 55
+#define CATENTRY 851
+#define CATCOMENTRY 56
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -235,7 +235,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[179]=dupstring( "Destination" );
   catalog[180]=dupstring( "Permissions" );
   catalog[181]=dupstring( "Add dir" );
-  catalog[182]=dupstring( "Edit dir" );
+  catalog[182]=dupstring( "Edit entry" );
   catalog[183]=dupstring( "Remove dir from list" );
   catalog[184]=dupstring( "Owner" );
   catalog[185]=dupstring( "Position" );
@@ -593,7 +593,7 @@ The default value here is the active entry and it's already correctly protected!
   catalog[526]=dupstring( "Error while writing to \"%s\"|Error:%s" );
   catalog[527]=dupstring( "octal:" );
   catalog[528]=dupstring( "Move was canceled but some files were correctly copied!|Shall I delete these files from the source?" );
-  catalog[529]=dupstring( " - %s %s/%s %s free" );
+  catalog[529]=dupstring( "" );
   catalog[530]=dupstring( "The following files/dirs in the directory %s couldn't be copied|because I didn't get information about them:" );
   catalog[531]=dupstring( "Can't get information about existing file|%s|because of this error:|%s" );
   catalog[532]=dupstring( "Can't read directory|%s|because of this error:|%s" );
@@ -894,7 +894,7 @@ match any font." );
   catalog[791]=dupstring( "Text view color for selection" );
   catalog[792]=dupstring( "Same filesystem only" );
   catalog[793]=dupstring( "Filter:" );
-  catalog[794]=dupstring( "Clear" );
+  catalog[794]=dupstring( "Show all" );
   catalog[795]=dupstring( "Libmagic pattern:" );
   catalog[796]=dupstring( "Use libmagic pattern" );
   catalog[797]=dupstring( "Test with file:" );
@@ -913,6 +913,44 @@ match any font." );
   catalog[810]=dupstring( "Alias" );
   catalog[811]=dupstring( "Decompress file" );
   catalog[812]=dupstring( "(in order of access [newest is bottom])" );
+  catalog[813]=dupstring( "Modified after" );
+  catalog[814]=dupstring( "Modified before" );
+  catalog[815]=dupstring( "Basic options" );
+  catalog[816]=dupstring( "More options" );
+  catalog[817]=dupstring( "File size >=" );
+  catalog[818]=dupstring( "File size <=" );
+  catalog[819]=dupstring( "Calendar" );
+  catalog[820]=dupstring( "The file size can be entered with the common suffixes kb, mb or gb|(or the SI units kib, mib, gib both with powers of 1024) and k, m or g (powers of 1000).|You may also enter floating-point numbers like 1.5mb." );
+  catalog[821]=dupstring( "Command execution aborted! The maximum recursion limit has been reached.|This usually happens due to a bug in your configuration when one of the|callback commands like show-action is used for a file type action.|If you think this is a bug in Worker then please contact the mailing list!" );
+  catalog[822]=dupstring( "Current label:" );
+  catalog[823]=dupstring( "Label" );
+  catalog[824]=dupstring( "all" );
+  catalog[825]=dupstring( "Change the colors of various bookmark related components" );
+  catalog[826]=dupstring( "List view colors for labeled entries:" );
+  catalog[827]=dupstring( "Add" );
+  catalog[828]=dupstring( "Remove" );
+  catalog[829]=dupstring( "Select label to set ot remove on active entry:" );
+  catalog[830]=dupstring( "Ask for label at runtime" );
+  catalog[831]=dupstring( "Choose label:" );
+  catalog[832]=dupstring( "Bookmark/Label colors" );
+  catalog[833]=dupstring( "Change label" );
+  catalog[834]=dupstring( "Remove label" );
+  catalog[835]=dupstring( "Choose to set or invert the selected options:" );
+  catalog[836]=dupstring( "Set settings" );
+  catalog[837]=dupstring( "Invert settings" );
+  catalog[838]=dupstring( "Change pattern based filters" );
+  catalog[839]=dupstring( "Change bookmark filter" );
+  catalog[840]=dupstring( "Bookmark filter:" );
+  catalog[841]=dupstring( "Show all entries" );
+  catalog[842]=dupstring( "Show only bookmarks" );
+  catalog[843]=dupstring( "Show only bookmark with given label" );
+  catalog[844]=dupstring( "Show bookmarks with label:" );
+  catalog[845]=dupstring( "Bookmark specific settings" );
+  catalog[846]=dupstring( "Also apply colors to base directories of a bookmark" );
+  catalog[847]=dupstring( "Add to bookmarks without label" );
+  catalog[848]=dupstring( "Show bookmarks with empty label" );
+  catalog[849]=dupstring( " - %s/%s free" );
+  catalog[850]=dupstring( "Query label on runtime" );
 
 //  catalog[]=dupstring( "" );
   
@@ -971,6 +1009,7 @@ match any font." );
   catalogcom[52]=dupstring( "Open context menu" );
   catalogcom[53]=dupstring( "Run custom action" );
   catalogcom[54]=dupstring( "Open Worker menu" );
+  catalogcom[55]=dupstring( "Change file label" );
   
   catalogflag[0]=dupstring( "Stringrequester" );
   catalogflag[1]=dupstring( "path" );
